@@ -8,8 +8,12 @@ pub mod v1_accelerator;
 pub use self::v1_accelerator::V1Accelerator;
 pub mod v1_create_sip_teleport;
 pub use self::v1_create_sip_teleport::V1CreateSipTeleport;
-pub mod v1_list_accelerators_response;
-pub use self::v1_list_accelerators_response::V1ListAcceleratorsResponse;
+pub mod v1_global_turn_response;
+pub use self::v1_global_turn_response::V1GlobalTurnResponse;
+pub mod v1_global_turn_server;
+pub use self::v1_global_turn_server::V1GlobalTurnServer;
+pub mod v1_list_accelerator_response;
+pub use self::v1_list_accelerator_response::V1ListAcceleratorResponse;
 pub mod v1_list_projects_response;
 pub use self::v1_list_projects_response::V1ListProjectsResponse;
 pub mod v1_list_sessions_response;
@@ -20,8 +24,6 @@ pub mod v1_next_page;
 pub use self::v1_next_page::V1NextPage;
 pub mod v1_project;
 pub use self::v1_project::V1Project;
-pub mod v1_protocol;
-pub use self::v1_protocol::V1Protocol;
 pub mod v1_session;
 pub use self::v1_session::V1Session;
 pub mod v1_sip_teleport_response;
